#
# spec file for package python-altair
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-altair
Version:        2.3.0
Release:        2.2
Summary:        Declarative statistical visualization library for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://altair-viz.github.io
Source:         https://files.pythonhosted.org/packages/source/a/altair/altair-%{version}.tar.gz
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module entrypoints}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module jupyter_ipython}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module toolz}
BuildRequires:  %{python_module typing}
BuildRequires:  %{python_module vega_datasets}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-entrypoints
Requires:       python-jsonschema
Requires:       python-numpy
Requires:       python-pandas
Requires:       python-six
Requires:       python-toolz
Requires:       python-typing
Recommends:     python-vega_datasets
Recommends:     python-jupyter_ipython
BuildArch:      noarch
%python_subpackages

%description
This package provides a Python API for building statistical visualizations
in a declarative manner. This API contains no actual visualization rendering
code, but instead emits JSON data structures following the `Vega-Lite`_
specification. For convenience, Altair can optionally use `ipyvega`_ to
seamlessly display client-side renderings in the Jupyter notebook.

%prep
%setup -q -n altair-%{version}

%build
%python_build

%install
%python_install

# Deduplicating files can generate a RPMLINT warning for pyc mtime
%{python_expand %fdupes %{buildroot}%{$python_sitearch}
$python    -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/altair/vega/v3/
$python -O -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/altair/vega/v3/
$python    -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/altair/vega/v4/
$python -O -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/altair/vega/v4/
%fdupes %{buildroot}%{$python_sitearch}
}

# Tests require a network connection
# %%check
# export LANG=en_US.UTF-8
# %%{python_expand export BUILDROOT=%%{buildroot}%{$python_sitelib}
# pytest-%%{$python_bin_suffix} altair
# }

%files %{python_files}
%doc CHANGES.md README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Jan  4 2019 toddrme2178@gmail.com
- Update to version 2.3.0
  * Includes many reworked examples in the example gallery.
  + Enhancements
  * Better errors for non-string column names, as well as automatic conversion
    of ``pandas.RangeIndex`` columns to strings (#1107)
  * Renderers now have set_embed_options() method (#1203)
  * Added kaggle renderer & more HTML output options (#1123)
  + Maintenance
  * fix typing requirement in Python 3.6+ (#1185)
  * Added support & CI testing for Python 3.7 (#1008)
  + Bug fixes
  * Selection predicates now recognize all valid entries (#1143)
  * Python 2 support for `chart.save()` (#1134)
- Update to version 2.2.2
  + Bug Fixes
  * fix missing JSON resource in ``altair.vega.v4`` (#1097)
- Update to version 2.1.0
  + Bug Fixes
  * appropriate handling of InlineData in dataset consolidation (#1092)
  * fix admonition formatting in documentation page (#1094)
- Update to version 2.2.0
  + Enhancements
  * better handling of datetimes and timezones (#1053)
  * all inline datasets are now converted to named datasets and stored at the
    top level of the chart. This behavior can be disabled by setting
    ``alt.data_transformers.consolidate_datasets = False`` (#951 & #1046)
  * more streamlined shorthand syntax for window transforms (#957)
  + Maintenance
  * update from Vega-Lite 2.4.3 to Vega-Lite 2.6.0; see vega-lite change-logs [2.5.0](https://github.com/vega/vega-lite/releases/tag/v2.5.0) [2.5.1](https://github.com/vega/vega-lite/releases/tag/v2.5.1) [2.5.2](https://github.com/vega/vega-lite/releases/tag/v2.5.2) [2.6.0](https://github.com/vega/vega-lite/releases/tag/v2.6.0)
  + Backward-incompatible changes
  * ``alt.SortField`` renamed to ``alt.EncodingSortField`` and
    ``alt.WindowSortField`` renamed to ``alt.SortField`` (#3741)
  + Bug Fixes
  * Fixed serialization of logical operands on selections within
    ``transform_filter()``: (#1075)
  * Fixed sphinx issue which embedded chart specs twice (#1088)
  * Avoid Selenium import until it is actually needed (#982)
- Update to version 2.1.0
  + Enhancements
  * add a ``scale_factor`` argument to ``chart.save()`` to allow the
    size/resolution of saved figures to be adjusted. (#918)
  * add an ``add_selection()`` method to add selections to charts (#832)
  * add ``chart.serve()`` and ``chart.display()`` methods for more flexibility
    in displaying charts (#831)
  * allow multiple fields to be passed to encodings such as ``tooltip``
    and ``detail`` (#830)
  * make ``timeUnit`` specifications more succinct, by parsing them in a manner
    similar to aggregates (#866)
  * make ``to_json()`` and ``to_csv()`` have deterministic filenames, so in json
    mode a single datasets will lead to a single on-disk serialization (#862)
  + Breaking Changes
  * make ``data`` the first argument for all compound chart types to match the
    semantics of ``alt.Chart`` (this includes ``alt.FacetChart``,
    ``alt.LayerChart``, ``alt.RepeatChart``, ``alt.VConcatChart``, and
    ``alt.HConcatChart``) (#895).
  * update vega-lite to version 2.4.3 (#836)
  * Only API change is internal: ``alt.MarkProperties`` is now ``alt.MarkConfig``
  + Maintenance
  * update vega to v3.3 & vega-embed to v3.11 in html output & colab renderer (#838)
- Remove no longer relevant python-altair-pandas.patch
* Fri May 18 2018 tchvatal@suse.com
- Remove bogus vega3 dependency
* Thu May 17 2018 tchvatal@suse.com
- Version update to 2.0.1:
  * Update all the dependencies to reflect reality
  * Many changes described mostly in the github commitlog
* Thu May 17 2018 tchvatal@suse.com
- Add patch to build with new python-pandas:
  * python-altair-pandas.patch
* Thu May  3 2018 toddrme2178@gmail.com
- Use %%license tag
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 1.2.1
  * Support for JupyterLab/nteract through MIME based rendering. Enable this by calling enable_mime_rendering() before rendering visualizations (#216).
  * Change default import in all code and docs to import altair as alt
  * Check for missing and misspelled column names upon exporting or rendering, and raise FieldError (#399) if any problems are found. This can be disabled by setting Chart.validated_columns=False.
  * Raise MaxRowsExceeded if the number of rows in the dataset is larger than Chart.max_rows to guard against sending large datasets to the browser.
  * Move the Vega-Lite 1.x api into altair.v1 to make it easier for us to migrate to Vega-Lite 2.x and continue to support 1.x. No import change are needed as altair.v1 is aliased to altair in this releasealtair.v1 (#377).
  * Moved the example notebooks into a separate repository (https://github.com/altair-viz/altair_notebooks) that has Binder support (#391).
  * Add $schema to top-level JSON spec (#370).
  * Minor documentation revisions.
- Remove upstream-included fix_mockserver_py36.patch
* Tue Aug 22 2017 toddrme2178@gmail.com
- Initial version
- Add fix_mockserver_py36.patch
  Should be included in next release
